# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from pydantic import Field as FieldInfo

from .._models import BaseModel
from .shared.references import References
from .shared.response_wrapper import ResponseWrapper

__all__ = ["CurrentTimeRetrieveResponse", "CurrentTimeRetrieveResponseData", "CurrentTimeRetrieveResponseDataEntry"]


class CurrentTimeRetrieveResponseDataEntry(BaseModel):
    readable_time: Optional[str] = FieldInfo(alias="readableTime", default=None)

    time: Optional[int] = None


class CurrentTimeRetrieveResponseData(BaseModel):
    entry: CurrentTimeRetrieveResponseDataEntry

    references: References


class CurrentTimeRetrieveResponse(ResponseWrapper):
    data: CurrentTimeRetrieveResponseData



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import TYPE_CHECKING, Any, Mapping
from typing_extensions import Self, override

import httpx

from . import _exceptions
from ._qs import Querystring
from ._types import (
    Omit,
    Timeout,
    NotGiven,
    Transport,
    ProxiesTypes,
    RequestOptions,
    not_given,
)
from ._utils import is_given, get_async_library
from ._compat import cached_property
from ._version import __version__
from ._streaming import Stream as Stream, AsyncStream as AsyncStream
from ._exceptions import APIStatusError, OnebusawaySDKError
from ._base_client import (
    DEFAULT_MAX_RETRIES,
    SyncAPIClient,
    AsyncAPIClient,
)

if TYPE_CHECKING:
    from .resources import (
        stop,
        trip,
        block,
        route,
        shape,
        agency,
        config,
        current_time,
        trip_details,
        search_for_stop,
        stops_for_route,
        trips_for_route,
        search_for_route,
        stops_for_agency,
        trip_for_vehicle,
        routes_for_agency,
        schedule_for_stop,
        schedule_for_route,
        stops_for_location,
        trips_for_location,
        routes_for_location,
        stop_ids_for_agency,
        vehicles_for_agency,
        route_ids_for_agency,
        arrival_and_departure,
        agencies_with_coverage,
        report_problem_with_stop,
        report_problem_with_trip,
    )
    from .resources.stop import StopResource, AsyncStopResource
    from .resources.trip import TripResource, AsyncTripResource
    from .resources.block import BlockResource, AsyncBlockResource
    from .resources.route import RouteResource, AsyncRouteResource
    from .resources.shape import ShapeResource, AsyncShapeResource
    from .resources.agency import AgencyResource, AsyncAgencyResource
    from .resources.config import ConfigResource, AsyncConfigResource
    from .resources.current_time import CurrentTimeResource, AsyncCurrentTimeResource
    from .resources.trip_details import TripDetailsResource, AsyncTripDetailsResource
    from .resources.search_for_stop import SearchForStopResource, AsyncSearchForStopResource
    from .resources.stops_for_route import StopsForRouteResource, AsyncStopsForRouteResource
    from .resources.trips_for_route import TripsForRouteResource, AsyncTripsForRouteResource
    from .resources.search_for_route import SearchForRouteResource, AsyncSearchForRouteResource
    from .resources.stops_for_agency import StopsForAgencyResource, AsyncStopsForAgencyResource
    from .resources.trip_for_vehicle import TripForVehicleResource, AsyncTripForVehicleResource
    from .resources.routes_for_agency import RoutesForAgencyResource, AsyncRoutesForAgencyResource
    from .resources.schedule_for_stop import ScheduleForStopResource, AsyncScheduleForStopResource
    from .resources.schedule_for_route import ScheduleForRouteResource, AsyncScheduleForRouteResource
    from .resources.stops_for_location import StopsForLocationResource, AsyncStopsForLocationResource
    from .resources.trips_for_location import TripsForLocationResource, AsyncTripsForLocationResource
    from .resources.routes_for_location import RoutesForLocationResource, AsyncRoutesForLocationResource
    from .resources.stop_ids_for_agency import StopIDsForAgencyResource, AsyncStopIDsForAgencyResource
    from .resources.vehicles_for_agency import VehiclesForAgencyResource, AsyncVehiclesForAgencyResource
    from .resources.route_ids_for_agency import RouteIDsForAgencyResource, AsyncRouteIDsForAgencyResource
    from .resources.arrival_and_departure import ArrivalAndDepartureResource, AsyncArrivalAndDepartureResource
    from .resources.agencies_with_coverage import AgenciesWithCoverageResource, AsyncAgenciesWithCoverageResource
    from .resources.report_problem_with_stop import ReportProblemWithStopResource, AsyncReportProblemWithStopResource
    from .resources.report_problem_with_trip import ReportProblemWithTripResource, AsyncReportProblemWithTripResource

__all__ = [
    "Timeout",
    "Transport",
    "ProxiesTypes",
    "RequestOptions",
    "OnebusawaySDK",
    "AsyncOnebusawaySDK",
    "Client",
    "AsyncClient",
]


class OnebusawaySDK(SyncAPIClient):
    # client options
    api_key: str

    def __init__(
        self,
        *,
        api_key: str | None = None,
        base_url: str | httpx.URL | None = None,
        timeout: float | Timeout | None | NotGiven = not_given,
        max_retries: int = DEFAULT_MAX_RETRIES,
        default_headers: Mapping[str, str] | None = None,
        default_query: Mapping[str, object] | None = None,
        # Configure a custom httpx client.
        # We provide a `DefaultHttpxClient` class that you can pass to retain the default values we use for `limits`, `timeout` & `follow_redirects`.
        # See the [httpx documentation](https://www.python-httpx.org/api/#client) for more details.
        http_client: httpx.Client | None = None,
        # Enable or disable schema validation for data returned by the API.
        # When enabled an error APIResponseValidationError is raised
        # if the API responds with invalid data for the expected schema.
        #
        # This parameter may be removed or changed in the future.
        # If you rely on this feature, please open a GitHub issue
        # outlining your use-case to help us decide if it should be
        # part of our public interface in the future.
        _strict_response_validation: bool = False,
    ) -> None:
        """Construct a new synchronous OnebusawaySDK client instance.

        This automatically infers the `api_key` argument from the `ONEBUSAWAY_API_KEY` environment variable if it is not provided.
        """
        if api_key is None:
            api_key = os.environ.get("ONEBUSAWAY_API_KEY")
        if api_key is None:
            raise OnebusawaySDKError(
                "The api_key client option must be set either by passing api_key to the client or by setting the ONEBUSAWAY_API_KEY environment variable"
            )
        self.api_key = api_key

        if base_url is None:
            base_url = os.environ.get("ONEBUSAWAY_SDK_BASE_URL")
        if base_url is None:
            base_url = f"https://api.pugetsound.onebusaway.org"

        super().__init__(
            version=__version__,
            base_url=base_url,
            max_retries=max_retries,
            timeout=timeout,
            http_client=http_client,
            custom_headers=default_headers,
            custom_query=default_query,
            _strict_response_validation=_strict_response_validation,
        )

    @cached_property
    def agencies_with_coverage(self) -> AgenciesWithCoverageResource:
        from .resources.agencies_with_coverage import AgenciesWithCoverageResource

        return AgenciesWithCoverageResource(self)

    @cached_property
    def agency(self) -> AgencyResource:
        from .resources.agency import AgencyResource

        return AgencyResource(self)

    @cached_property
    def vehicles_for_agency(self) -> VehiclesForAgencyResource:
        from .resources.vehicles_for_agency import VehiclesForAgencyResource

        return VehiclesForAgencyResource(self)

    @cached_property
    def config(self) -> ConfigResource:
        from .resources.config import ConfigResource

        return ConfigResource(self)

    @cached_property
    def current_time(self) -> CurrentTimeResource:
        from .resources.current_time import CurrentTimeResource

        return CurrentTimeResource(self)

    @cached_property
    def stops_for_location(self) -> StopsForLocationResource:
        from .resources.stops_for_location import StopsForLocationResource

        return StopsForLocationResource(self)

    @cached_property
    def stops_for_route(self) -> StopsForRouteResource:
        from .resources.stops_for_route import StopsForRouteResource

        return StopsForRouteResource(self)

    @cached_property
    def stops_for_agency(self) -> StopsForAgencyResource:
        from .resources.stops_for_agency import StopsForAgencyResource

        return StopsForAgencyResource(self)

    @cached_property
    def stop(self) -> StopResource:
        from .resources.stop import StopResource

        return StopResource(self)

    @cached_property
    def stop_ids_for_agency(self) -> StopIDsForAgencyResource:
        from .resources.stop_ids_for_agency import StopIDsForAgencyResource

        return StopIDsForAgencyResource(self)

    @cached_property
    def schedule_for_stop(self) -> ScheduleForStopResource:
        from .resources.schedule_for_stop import ScheduleForStopResource

        return ScheduleForStopResource(self)

    @cached_property
    def route(self) -> RouteResource:
        from .resources.route import RouteResource

        return RouteResource(self)

    @cached_property
    def route_ids_for_agency(self) -> RouteIDsForAgencyResource:
        from .resources.route_ids_for_agency import RouteIDsForAgencyResource

        return RouteIDsForAgencyResource(self)

    @cached_property
    def routes_for_location(self) -> RoutesForLocationResource:
        from .resources.routes_for_location import RoutesForLocationResource

        return RoutesForLocationResource(self)

    @cached_property
    def routes_for_agency(self) -> RoutesForAgencyResource:
        from .resources.routes_for_agency import RoutesForAgencyResource

        return RoutesForAgencyResource(self)

    @cached_property
    def schedule_for_route(self) -> ScheduleForRouteResource:
        from .resources.schedule_for_route import ScheduleForRouteResource

        return ScheduleForRouteResource(self)

    @cached_property
    def arrival_and_departure(self) -> ArrivalAndDepartureResource:
        from .resources.arrival_and_departure import ArrivalAndDepartureResource

        return ArrivalAndDepartureResource(self)

    @cached_property
    def trip(self) -> TripResource:
        from .resources.trip import TripResource

        return TripResource(self)

    @cached_property
    def trips_for_location(self) -> TripsForLocationResource:
        from .resources.trips_for_location import TripsForLocationResource

        return TripsForLocationResource(self)

    @cached_property
    def trip_details(self) -> TripDetailsResource:
        from .resources.trip_details import TripDetailsResource

        return TripDetailsResource(self)

    @cached_property
    def trip_for_vehicle(self) -> TripForVehicleResource:
        from .resources.trip_for_vehicle import TripForVehicleResource

        return TripForVehicleResource(self)

    @cached_property
    def trips_for_route(self) -> TripsForRouteResource:
        from .resources.trips_for_route import TripsForRouteResource

        return TripsForRouteResource(self)

    @cached_property
    def report_problem_with_stop(self) -> ReportProblemWithStopResource:
        from .resources.report_problem_with_stop import ReportProblemWithStopResource

        return ReportProblemWithStopResource(self)

    @cached_property
    def report_problem_with_trip(self) -> ReportProblemWithTripResource:
        from .resources.report_problem_with_trip import ReportProblemWithTripResource

        return ReportProblemWithTripResource(self)

    @cached_property
    def search_for_stop(self) -> SearchForStopResource:
        from .resources.search_for_stop import SearchForStopResource

        return SearchForStopResource(self)

    @cached_property
    def search_for_route(self) -> SearchForRouteResource:
        from .resources.search_for_route import SearchForRouteResource

        return SearchForRouteResource(self)

    @cached_property
    def block(self) -> BlockResource:
        from .resources.block import BlockResource

        return BlockResource(self)

    @cached_property
    def shape(self) -> ShapeResource:
        from .resources.shape import ShapeResource

        return ShapeResource(self)

    @cached_property
    def with_raw_response(self) -> OnebusawaySDKWithRawResponse:
        return OnebusawaySDKWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> OnebusawaySDKWithStreamedResponse:
        return OnebusawaySDKWithStreamedResponse(self)

    @property
    @override
    def qs(self) -> Querystring:
        return Querystring(array_format="repeat")

    @property
    @override
    def auth_headers(self) -> dict[str, str]:
        return {}

    @property
    @override
    def default_headers(self) -> dict[str, str | Omit]:
        return {
            **super().default_headers,
            "X-Stainless-Async": "false",
            **self._custom_headers,
        }

    @property
    @override
    def default_query(self) -> dict[str, object]:
        return {
            **super().default_query,
            "key": self.api_key,
            **self._custom_query,
        }

    def copy(
        self,
        *,
        api_key: str | None = None,
        base_url: str | httpx.URL | None = None,
        timeout: float | Timeout | None | NotGiven = not_given,
        http_client: httpx.Client | None = None,
        max_retries: int | NotGiven = not_given,
        default_headers: Mapping[str, str] | None = None,
        set_default_headers: Mapping[str, str] | None = None,
        default_query: Mapping[str, object] | None = None,
        set_default_query: Mapping[str, object] | None = None,
        _extra_kwargs: Mapping[str, Any] = {},
    ) -> Self:
        """
        Create a new client instance re-using the same options given to the current client with optional overriding.
        """
        if default_headers is not None and set_default_headers is not None:
            raise ValueError("The `default_headers` and `set_default_headers` arguments are mutually exclusive")

        if default_query is not None and set_default_query is not None:
            raise ValueError("The `default_query` and `set_default_query` arguments are mutually exclusive")

        headers = self._custom_headers
        if default_headers is not None:
            headers = {**headers, **default_headers}
        elif set_default_headers is not None:
            headers = set_default_headers

        params = self._custom_query
        if default_query is not None:
            params = {**params, **default_query}
        elif set_default_query is not None:
            params = set_default_query

        http_client = http_client or self._client
        return self.__class__(
            api_key=api_key or self.api_key,
            base_url=base_url or self.base_url,
            timeout=self.timeout if isinstance(timeout, NotGiven) else timeout,
            http_client=http_client,
            max_retries=max_retries if is_given(max_retries) else self.max_retries,
            default_headers=headers,
            default_query=params,
            **_extra_kwargs,
        )

    # Alias for `copy` for nicer inline usage, e.g.
    # client.with_options(timeout=10).foo.create(...)
    with_options = copy

    def _get_api_key_query_param(self) -> str | None:
        return self.api_key

    @override
    def _make_status_error(
        self,
        err_msg: str,
        *,
        body: object,
        response: httpx.Response,
    ) -> APIStatusError:
        if response.status_code == 400:
            return _exceptions.BadRequestError(err_msg, response=response, body=body)

        if response.status_code == 401:
            return _exceptions.AuthenticationError(err_msg, response=response, body=body)

        if response.status_code == 403:
            return _exceptions.PermissionDeniedError(err_msg, response=response, body=body)

        if response.status_code == 404:
            return _exceptions.NotFoundError(err_msg, response=response, body=body)

        if response.status_code == 409:
            return _exceptions.ConflictError(err_msg, response=response, body=body)

        if response.status_code == 422:
            return _exceptions.UnprocessableEntityError(err_msg, response=response, body=body)

        if response.status_code == 429:
            return _exceptions.RateLimitError(err_msg, response=response, body=body)

        if response.status_code >= 500:
            return _exceptions.InternalServerError(err_msg, response=response, body=body)
        return APIStatusError(err_msg, response=response, body=body)


class AsyncOnebusawaySDK(AsyncAPIClient):
    # client options
    api_key: str

    def __init__(
        self,
        *,
        api_key: str | None = None,
        base_url: str | httpx.URL | None = None,
        timeout: float | Timeout | None | NotGiven = not_given,
        max_retries: int = DEFAULT_MAX_RETRIES,
        default_headers: Mapping[str, str] | None = None,
        default_query: Mapping[str, object] | None = None,
        # Configure a custom httpx client.
        # We provide a `DefaultAsyncHttpxClient` class that you can pass to retain the default values we use for `limits`, `timeout` & `follow_redirects`.
        # See the [httpx documentation](https://www.python-httpx.org/api/#asyncclient) for more details.
        http_client: httpx.AsyncClient | None = None,
        # Enable or disable schema validation for data returned by the API.
        # When enabled an error APIResponseValidationError is raised
        # if the API responds with invalid data for the expected schema.
        #
        # This parameter may be removed or changed in the future.
        # If you rely on this feature, please open a GitHub issue
        # outlining your use-case to help us decide if it should be
        # part of our public interface in the future.
        _strict_response_validation: bool = False,
    ) -> None:
        """Construct a new async AsyncOnebusawaySDK client instance.

        This automatically infers the `api_key` argument from the `ONEBUSAWAY_API_KEY` environment variable if it is not provided.
        """
        if api_key is None:
            api_key = os.environ.get("ONEBUSAWAY_API_KEY")
        if api_key is None:
            raise OnebusawaySDKError(
                "The api_key client option must be set either by passing api_key to the client or by setting the ONEBUSAWAY_API_KEY environment variable"
            )
        self.api_key = api_key

        if base_url is None:
            base_url = os.environ.get("ONEBUSAWAY_SDK_BASE_URL")
        if base_url is None:
            base_url = f"https://api.pugetsound.onebusaway.org"

        super().__init__(
            version=__version__,
            base_url=base_url,
            max_retries=max_retries,
            timeout=timeout,
            http_client=http_client,
            custom_headers=default_headers,
            custom_query=default_query,
            _strict_response_validation=_strict_response_validation,
        )

    @cached_property
    def agencies_with_coverage(self) -> AsyncAgenciesWithCoverageResource:
        from .resources.agencies_with_coverage import AsyncAgenciesWithCoverageResource

        return AsyncAgenciesWithCoverageResource(self)

    @cached_property
    def agency(self) -> AsyncAgencyResource:
        from .resources.agency import AsyncAgencyResource

        return AsyncAgencyResource(self)

    @cached_property
    def vehicles_for_agency(self) -> AsyncVehiclesForAgencyResource:
        from .resources.vehicles_for_agency import AsyncVehiclesForAgencyResource

        return AsyncVehiclesForAgencyResource(self)

    @cached_property
    def config(self) -> AsyncConfigResource:
        from .resources.config import AsyncConfigResource

        return AsyncConfigResource(self)

    @cached_property
    def current_time(self) -> AsyncCurrentTimeResource:
        from .resources.current_time import AsyncCurrentTimeResource

        return AsyncCurrentTimeResource(self)

    @cached_property
    def stops_for_location(self) -> AsyncStopsForLocationResource:
        from .resources.stops_for_location import AsyncStopsForLocationResource

        return AsyncStopsForLocationResource(self)

    @cached_property
    def stops_for_route(self) -> AsyncStopsForRouteResource:
        from .resources.stops_for_route import AsyncStopsForRouteResource

        return AsyncStopsForRouteResource(self)

    @cached_property
    def stops_for_agency(self) -> AsyncStopsForAgencyResource:
        from .resources.stops_for_agency import AsyncStopsForAgencyResource

        return AsyncStopsForAgencyResource(self)

    @cached_property
    def stop(self) -> AsyncStopResource:
        from .resources.stop import AsyncStopResource

        return AsyncStopResource(self)

    @cached_property
    def stop_ids_for_agency(self) -> AsyncStopIDsForAgencyResource:
        from .resources.stop_ids_for_agency import AsyncStopIDsForAgencyResource

        return AsyncStopIDsForAgencyResource(self)

    @cached_property
    def schedule_for_stop(self) -> AsyncScheduleForStopResource:
        from .resources.schedule_for_stop import AsyncScheduleForStopResource

        return AsyncScheduleForStopResource(self)

    @cached_property
    def route(self) -> AsyncRouteResource:
        from .resources.route import AsyncRouteResource

        return AsyncRouteResource(self)

    @cached_property
    def route_ids_for_agency(self) -> AsyncRouteIDsForAgencyResource:
        from .resources.route_ids_for_agency import AsyncRouteIDsForAgencyResource

        return AsyncRouteIDsForAgencyResource(self)

    @cached_property
    def routes_for_location(self) -> AsyncRoutesForLocationResource:
        from .resources.routes_for_location import AsyncRoutesForLocationResource

        return AsyncRoutesForLocationResource(self)

    @cached_property
    def routes_for_agency(self) -> AsyncRoutesForAgencyResource:
        from .resources.routes_for_agency import AsyncRoutesForAgencyResource

        return AsyncRoutesForAgencyResource(self)

    @cached_property
    def schedule_for_route(self) -> AsyncScheduleForRouteResource:
        from .resources.schedule_for_route import AsyncScheduleForRouteResource

        return AsyncScheduleForRouteResource(self)

    @cached_property
    def arrival_and_departure(self) -> AsyncArrivalAndDepartureResource:
        from .resources.arrival_and_departure import AsyncArrivalAndDepartureResource

        return AsyncArrivalAndDepartureResource(self)

    @cached_property
    def trip(self) -> AsyncTripResource:
        from .resources.trip import AsyncTripResource

        return AsyncTripResource(self)

    @cached_property
    def trips_for_location(self) -> AsyncTripsForLocationResource:
        from .resources.trips_for_location import AsyncTripsForLocationResource

        return AsyncTripsForLocationResource(self)

    @cached_property
    def trip_details(self) -> AsyncTripDetailsResource:
        from .resources.trip_details import AsyncTripDetailsResource

        return AsyncTripDetailsResource(self)

    @cached_property
    def trip_for_vehicle(self) -> AsyncTripForVehicleResource:
        from .resources.trip_for_vehicle import AsyncTripForVehicleResource

        return AsyncTripForVehicleResource(self)

    @cached_property
    def trips_for_route(self) -> AsyncTripsForRouteResource:
        from .resources.trips_for_route import AsyncTripsForRouteResource

        return AsyncTripsForRouteResource(self)

    @cached_property
    def report_problem_with_stop(self) -> AsyncReportProblemWithStopResource:
        from .resources.report_problem_with_stop import AsyncReportProblemWithStopResource

        return AsyncReportProblemWithStopResource(self)

    @cached_property
    def report_problem_with_trip(self) -> AsyncReportProblemWithTripResource:
        from .resources.report_problem_with_trip import AsyncReportProblemWithTripResource

        return AsyncReportProblemWithTripResource(self)

    @cached_property
    def search_for_stop(self) -> AsyncSearchForStopResource:
        from .resources.search_for_stop import AsyncSearchForStopResource

        return AsyncSearchForStopResource(self)

    @cached_property
    def search_for_route(self) -> AsyncSearchForRouteResource:
        from .resources.search_for_route import AsyncSearchForRouteResource

        return AsyncSearchForRouteResource(self)

    @cached_property
    def block(self) -> AsyncBlockResource:
        from .resources.block import AsyncBlockResource

        return AsyncBlockResource(self)

    @cached_property
    def shape(self) -> AsyncShapeResource:
        from .resources.shape import AsyncShapeResource

        return AsyncShapeResource(self)

    @cached_property
    def with_raw_response(self) -> AsyncOnebusawaySDKWithRawResponse:
        return AsyncOnebusawaySDKWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncOnebusawaySDKWithStreamedResponse:
        return AsyncOnebusawaySDKWithStreamedResponse(self)

    @property
    @override
    def qs(self) -> Querystring:
        return Querystring(array_format="repeat")

    @property
    @override
    def auth_headers(self) -> dict[str, str]:
        return {}

    @property
    @override
    def default_headers(self) -> dict[str, str | Omit]:
        return {
            **super().default_headers,
            "X-Stainless-Async": f"async:{get_async_library()}",
            **self._custom_headers,
        }

    @property
    @override
    def default_query(self) -> dict[str, object]:
        return {
            **super().default_query,
            "key": self.api_key,
            **self._custom_query,
        }

    def copy(
        self,
        *,
        api_key: str | None = None,
        base_url: str | httpx.URL | None = None,
        timeout: float | Timeout | None | NotGiven = not_given,
        http_client: httpx.AsyncClient | None = None,
        max_retries: int | NotGiven = not_given,
        default_headers: Mapping[str, str] | None = None,
        set_default_headers: Mapping[str, str] | None = None,
        default_query: Mapping[str, object] | None = None,
        set_default_query: Mapping[str, object] | None = None,
        _extra_kwargs: Mapping[str, Any] = {},
    ) -> Self:
        """
        Create a new client instance re-using the same options given to the current client with optional overriding.
        """
        if default_headers is not None and set_default_headers is not None:
            raise ValueError("The `default_headers` and `set_default_headers` arguments are mutually exclusive")

        if default_query is not None and set_default_query is not None:
            raise ValueError("The `default_query` and `set_default_query` arguments are mutually exclusive")

        headers = self._custom_headers
        if default_headers is not None:
            headers = {**headers, **default_headers}
        elif set_default_headers is not None:
            headers = set_default_headers

        params = self._custom_query
        if default_query is not None:
            params = {**params, **default_query}
        elif set_default_query is not None:
            params = set_default_query

        http_client = http_client or self._client
        return self.__class__(
            api_key=api_key or self.api_key,
            base_url=base_url or self.base_url,
            timeout=self.timeout if isinstance(timeout, NotGiven) else timeout,
            http_client=http_client,
            max_retries=max_retries if is_given(max_retries) else self.max_retries,
            default_headers=headers,
            default_query=params,
            **_extra_kwargs,
        )

    # Alias for `copy` for nicer inline usage, e.g.
    # client.with_options(timeout=10).foo.create(...)
    with_options = copy

    def _get_api_key_query_param(self) -> str | None:
        return self.api_key

    @override
    def _make_status_error(
        self,
        err_msg: str,
        *,
        body: object,
        response: httpx.Response,
    ) -> APIStatusError:
        if response.status_code == 400:
            return _exceptions.BadRequestError(err_msg, response=response, body=body)

        if response.status_code == 401:
            return _exceptions.AuthenticationError(err_msg, response=response, body=body)

        if response.status_code == 403:
            return _exceptions.PermissionDeniedError(err_msg, response=response, body=body)

        if response.status_code == 404:
            return _exceptions.NotFoundError(err_msg, response=response, body=body)

        if response.status_code == 409:
            return _exceptions.ConflictError(err_msg, response=response, body=body)

        if response.status_code == 422:
            return _exceptions.UnprocessableEntityError(err_msg, response=response, body=body)

        if response.status_code == 429:
            return _exceptions.RateLimitError(err_msg, response=response, body=body)

        if response.status_code >= 500:
            return _exceptions.InternalServerError(err_msg, response=response, body=body)
        return APIStatusError(err_msg, response=response, body=body)


class OnebusawaySDKWithRawResponse:
    _client: OnebusawaySDK

    def __init__(self, client: OnebusawaySDK) -> None:
        self._client = client

    @cached_property
    def agencies_with_coverage(self) -> agencies_with_coverage.AgenciesWithCoverageResourceWithRawResponse:
        from .resources.agencies_with_coverage import AgenciesWithCoverageResourceWithRawResponse

        return AgenciesWithCoverageResourceWithRawResponse(self._client.agencies_with_coverage)

    @cached_property
    def agency(self) -> agency.AgencyResourceWithRawResponse:
        from .resources.agency import AgencyResourceWithRawResponse

        return AgencyResourceWithRawResponse(self._client.agency)

    @cached_property
    def vehicles_for_agency(self) -> vehicles_for_agency.VehiclesForAgencyResourceWithRawResponse:
        from .resources.vehicles_for_agency import VehiclesForAgencyResourceWithRawResponse

        return VehiclesForAgencyResourceWithRawResponse(self._client.vehicles_for_agency)

    @cached_property
    def config(self) -> config.ConfigResourceWithRawResponse:
        from .resources.config import ConfigResourceWithRawResponse

        return ConfigResourceWithRawResponse(self._client.config)

    @cached_property
    def current_time(self) -> current_time.CurrentTimeResourceWithRawResponse:
        from .resources.current_time import CurrentTimeResourceWithRawResponse

        return CurrentTimeResourceWithRawResponse(self._client.current_time)

    @cached_property
    def stops_for_location(self) -> stops_for_location.StopsForLocationResourceWithRawResponse:
        from .resources.stops_for_location import StopsForLocationResourceWithRawResponse

        return StopsForLocationResourceWithRawResponse(self._client.stops_for_location)

    @cached_property
    def stops_for_route(self) -> stops_for_route.StopsForRouteResourceWithRawResponse:
        from .resources.stops_for_route import StopsForRouteResourceWithRawResponse

        return StopsForRouteResourceWithRawResponse(self._client.stops_for_route)

    @cached_property
    def stops_for_agency(self) -> stops_for_agency.StopsForAgencyResourceWithRawResponse:
        from .resources.stops_for_agency import StopsForAgencyResourceWithRawResponse

        return StopsForAgencyResourceWithRawResponse(self._client.stops_for_agency)

    @cached_property
    def stop(self) -> stop.StopResourceWithRawResponse:
        from .resources.stop import StopResourceWithRawResponse

        return StopResourceWithRawResponse(self._client.stop)

    @cached_property
    def stop_ids_for_agency(self) -> stop_ids_for_agency.StopIDsForAgencyResourceWithRawResponse:
        from .resources.stop_ids_for_agency import StopIDsForAgencyResourceWithRawResponse

        return StopIDsForAgencyResourceWithRawResponse(self._client.stop_ids_for_agency)

    @cached_property
    def schedule_for_stop(self) -> schedule_for_stop.ScheduleForStopResourceWithRawResponse:
        from .resources.schedule_for_stop import ScheduleForStopResourceWithRawResponse

        return ScheduleForStopResourceWithRawResponse(self._client.schedule_for_stop)

    @cached_property
    def route(self) -> route.RouteResourceWithRawResponse:
        from .resources.route import RouteResourceWithRawResponse

        return RouteResourceWithRawResponse(self._client.route)

    @cached_property
    def route_ids_for_agency(self) -> route_ids_for_agency.RouteIDsForAgencyResourceWithRawResponse:
        from .resources.route_ids_for_agency import RouteIDsForAgencyResourceWithRawResponse

        return RouteIDsForAgencyResourceWithRawResponse(self._client.route_ids_for_agency)

    @cached_property
    def routes_for_location(self) -> routes_for_location.RoutesForLocationResourceWithRawResponse:
        from .resources.routes_for_location import RoutesForLocationResourceWithRawResponse

        return RoutesForLocationResourceWithRawResponse(self._client.routes_for_location)

    @cached_property
    def routes_for_agency(self) -> routes_for_agency.RoutesForAgencyResourceWithRawResponse:
        from .resources.routes_for_agency import RoutesForAgencyResourceWithRawResponse

        return RoutesForAgencyResourceWithRawResponse(self._client.routes_for_agency)

    @cached_property
    def schedule_for_route(self) -> schedule_for_route.ScheduleForRouteResourceWithRawResponse:
        from .resources.schedule_for_route import ScheduleForRouteResourceWithRawResponse

        return ScheduleForRouteResourceWithRawResponse(self._client.schedule_for_route)

    @cached_property
    def arrival_and_departure(self) -> arrival_and_departure.ArrivalAndDepartureResourceWithRawResponse:
        from .resources.arrival_and_departure import ArrivalAndDepartureResourceWithRawResponse

        return ArrivalAndDepartureResourceWithRawResponse(self._client.arrival_and_departure)

    @cached_property
    def trip(self) -> trip.TripResourceWithRawResponse:
        from .resources.trip import TripResourceWithRawResponse

        return TripResourceWithRawResponse(self._client.trip)

    @cached_property
    def trips_for_location(self) -> trips_for_location.TripsForLocationResourceWithRawResponse:
        from .resources.trips_for_location import TripsForLocationResourceWithRawResponse

        return TripsForLocationResourceWithRawResponse(self._client.trips_for_location)

    @cached_property
    def trip_details(self) -> trip_details.TripDetailsResourceWithRawResponse:
        from .resources.trip_details import TripDetailsResourceWithRawResponse

        return TripDetailsResourceWithRawResponse(self._client.trip_details)

    @cached_property
    def trip_for_vehicle(self) -> trip_for_vehicle.TripForVehicleResourceWithRawResponse:
        from .resources.trip_for_vehicle import TripForVehicleResourceWithRawResponse

        return TripForVehicleResourceWithRawResponse(self._client.trip_for_vehicle)

    @cached_property
    def trips_for_route(self) -> trips_for_route.TripsForRouteResourceWithRawResponse:
        from .resources.trips_for_route import TripsForRouteResourceWithRawResponse

        return TripsForRouteResourceWithRawResponse(self._client.trips_for_route)

    @cached_property
    def report_problem_with_stop(self) -> report_problem_with_stop.ReportProblemWithStopResourceWithRawResponse:
        from .resources.report_problem_with_stop import ReportProblemWithStopResourceWithRawResponse

        return ReportProblemWithStopResourceWithRawResponse(self._client.report_problem_with_stop)

    @cached_property
    def report_problem_with_trip(self) -> report_problem_with_trip.ReportProblemWithTripResourceWithRawResponse:
        from .resources.report_problem_with_trip import ReportProblemWithTripResourceWithRawResponse

        return ReportProblemWithTripResourceWithRawResponse(self._client.report_problem_with_trip)

    @cached_property
    def search_for_stop(self) -> search_for_stop.SearchForStopResourceWithRawResponse:
        from .resources.search_for_stop import SearchForStopResourceWithRawResponse

        return SearchForStopResourceWithRawResponse(self._client.search_for_stop)

    @cached_property
    def search_for_route(self) -> search_for_route.SearchForRouteResourceWithRawResponse:
        from .resources.search_for_route import SearchForRouteResourceWithRawResponse

        return SearchForRouteResourceWithRawResponse(self._client.search_for_route)

    @cached_property
    def block(self) -> block.BlockResourceWithRawResponse:
        from .resources.block import BlockResourceWithRawResponse

        return BlockResourceWithRawResponse(self._client.block)

    @cached_property
    def shape(self) -> shape.ShapeResourceWithRawResponse:
        from .resources.shape import ShapeResourceWithRawResponse

        return ShapeResourceWithRawResponse(self._client.shape)


class AsyncOnebusawaySDKWithRawResponse:
    _client: AsyncOnebusawaySDK

    def __init__(self, client: AsyncOnebusawaySDK) -> None:
        self._client = client

    @cached_property
    def agencies_with_coverage(self) -> agencies_with_coverage.AsyncAgenciesWithCoverageResourceWithRawResponse:
        from .resources.agencies_with_coverage import AsyncAgenciesWithCoverageResourceWithRawResponse

        return AsyncAgenciesWithCoverageResourceWithRawResponse(self._client.agencies_with_coverage)

    @cached_property
    def agency(self) -> agency.AsyncAgencyResourceWithRawResponse:
        from .resources.agency import AsyncAgencyResourceWithRawResponse

        return AsyncAgencyResourceWithRawResponse(self._client.agency)

    @cached_property
    def vehicles_for_agency(self) -> vehicles_for_agency.AsyncVehiclesForAgencyResourceWithRawResponse:
        from .resources.vehicles_for_agency import AsyncVehiclesForAgencyResourceWithRawResponse

        return AsyncVehiclesForAgencyResourceWithRawResponse(self._client.vehicles_for_agency)

    @cached_property
    def config(self) -> config.AsyncConfigResourceWithRawResponse:
        from .resources.config import AsyncConfigResourceWithRawResponse

        return AsyncConfigResourceWithRawResponse(self._client.config)

    @cached_property
    def current_time(self) -> current_time.AsyncCurrentTimeResourceWithRawResponse:
        from .resources.current_time import AsyncCurrentTimeResourceWithRawResponse

        return AsyncCurrentTimeResourceWithRawResponse(self._client.current_time)

    @cached_property
    def stops_for_location(self) -> stops_for_location.AsyncStopsForLocationResourceWithRawResponse:
        from .resources.stops_for_location import AsyncStopsForLocationResourceWithRawResponse

        return AsyncStopsForLocationResourceWithRawResponse(self._client.stops_for_location)

    @cached_property
    def stops_for_route(self) -> stops_for_route.AsyncStopsForRouteResourceWithRawResponse:
        from .resources.stops_for_route import AsyncStopsForRouteResourceWithRawResponse

        return AsyncStopsForRouteResourceWithRawResponse(self._client.stops_for_route)

    @cached_property
    def stops_for_agency(self) -> stops_for_agency.AsyncStopsForAgencyResourceWithRawResponse:
        from .resources.stops_for_agency import AsyncStopsForAgencyResourceWithRawResponse

        return AsyncStopsForAgencyResourceWithRawResponse(self._client.stops_for_agency)

    @cached_property
    def stop(self) -> stop.AsyncStopResourceWithRawResponse:
        from .resources.stop import AsyncStopResourceWithRawResponse

        return AsyncStopResourceWithRawResponse(self._client.stop)

    @cached_property
    def stop_ids_for_agency(self) -> stop_ids_for_agency.AsyncStopIDsForAgencyResourceWithRawResponse:
        from .resources.stop_ids_for_agency import AsyncStopIDsForAgencyResourceWithRawResponse

        return AsyncStopIDsForAgencyResourceWithRawResponse(self._client.stop_ids_for_agency)

    @cached_property
    def schedule_for_stop(self) -> schedule_for_stop.AsyncScheduleForStopResourceWithRawResponse:
        from .resources.schedule_for_stop import AsyncScheduleForStopResourceWithRawResponse

        return AsyncScheduleForStopResourceWithRawResponse(self._client.schedule_for_stop)

    @cached_property
    def route(self) -> route.AsyncRouteResourceWithRawResponse:
        from .resources.route import AsyncRouteResourceWithRawResponse

        return AsyncRouteResourceWithRawResponse(self._client.route)

    @cached_property
    def route_ids_for_agency(self) -> route_ids_for_agency.AsyncRouteIDsForAgencyResourceWithRawResponse:
        from .resources.route_ids_for_agency import AsyncRouteIDsForAgencyResourceWithRawResponse

        return AsyncRouteIDsForAgencyResourceWithRawResponse(self._client.route_ids_for_agency)

    @cached_property
    def routes_for_location(self) -> routes_for_location.AsyncRoutesForLocationResourceWithRawResponse:
        from .resources.routes_for_location import AsyncRoutesForLocationResourceWithRawResponse

        return AsyncRoutesForLocationResourceWithRawResponse(self._client.routes_for_location)

    @cached_property
    def routes_for_agency(self) -> routes_for_agency.AsyncRoutesForAgencyResourceWithRawResponse:
        from .resources.routes_for_agency import AsyncRoutesForAgencyResourceWithRawResponse

        return AsyncRoutesForAgencyResourceWithRawResponse(self._client.routes_for_agency)

    @cached_property
    def schedule_for_route(self) -> schedule_for_route.AsyncScheduleForRouteResourceWithRawResponse:
        from .resources.schedule_for_route import AsyncScheduleForRouteResourceWithRawResponse

        return AsyncScheduleForRouteResourceWithRawResponse(self._client.schedule_for_route)

    @cached_property
    def arrival_and_departure(self) -> arrival_and_departure.AsyncArrivalAndDepartureResourceWithRawResponse:
        from .resources.arrival_and_departure import AsyncArrivalAndDepartureResourceWithRawResponse

        return AsyncArrivalAndDepartureResourceWithRawResponse(self._client.arrival_and_departure)

    @cached_property
    def trip(self) -> trip.AsyncTripResourceWithRawResponse:
        from .resources.trip import AsyncTripResourceWithRawResponse

        return AsyncTripResourceWithRawResponse(self._client.trip)

    @cached_property
    def trips_for_location(self) -> trips_for_location.AsyncTripsForLocationResourceWithRawResponse:
        from .resources.trips_for_location import AsyncTripsForLocationResourceWithRawResponse

        return AsyncTripsForLocationResourceWithRawResponse(self._client.trips_for_location)

    @cached_property
    def trip_details(self) -> trip_details.AsyncTripDetailsResourceWithRawResponse:
        from .resources.trip_details import AsyncTripDetailsResourceWithRawResponse

        return AsyncTripDetailsResourceWithRawResponse(self._client.trip_details)

    @cached_property
    def trip_for_vehicle(self) -> trip_for_vehicle.AsyncTripForVehicleResourceWithRawResponse:
        from .resources.trip_for_vehicle import AsyncTripForVehicleResourceWithRawResponse

        return AsyncTripForVehicleResourceWithRawResponse(self._client.trip_for_vehicle)

    @cached_property
    def trips_for_route(self) -> trips_for_route.AsyncTripsForRouteResourceWithRawResponse:
        from .resources.trips_for_route import AsyncTripsForRouteResourceWithRawResponse

        return AsyncTripsForRouteResourceWithRawResponse(self._client.trips_for_route)

    @cached_property
    def report_problem_with_stop(self) -> report_problem_with_stop.AsyncReportProblemWithStopResourceWithRawResponse:
        from .resources.report_problem_with_stop import AsyncReportProblemWithStopResourceWithRawResponse

        return AsyncReportProblemWithStopResourceWithRawResponse(self._client.report_problem_with_stop)

    @cached_property
    def report_problem_with_trip(self) -> report_problem_with_trip.AsyncReportProblemWithTripResourceWithRawResponse:
        from .resources.report_problem_with_trip import AsyncReportProblemWithTripResourceWithRawResponse

        return AsyncReportProblemWithTripResourceWithRawResponse(self._client.report_problem_with_trip)

    @cached_property
    def search_for_stop(self) -> search_for_stop.AsyncSearchForStopResourceWithRawResponse:
        from .resources.search_for_stop import AsyncSearchForStopResourceWithRawResponse

        return AsyncSearchForStopResourceWithRawResponse(self._client.search_for_stop)

    @cached_property
    def search_for_route(self) -> search_for_route.AsyncSearchForRouteResourceWithRawResponse:
        from .resources.search_for_route import AsyncSearchForRouteResourceWithRawResponse

        return AsyncSearchForRouteResourceWithRawResponse(self._client.search_for_route)

    @cached_property
    def block(self) -> block.AsyncBlockResourceWithRawResponse:
        from .resources.block import AsyncBlockResourceWithRawResponse

        return AsyncBlockResourceWithRawResponse(self._client.block)

    @cached_property
    def shape(self) -> shape.AsyncShapeResourceWithRawResponse:
        from .resources.shape import AsyncShapeResourceWithRawResponse

        return AsyncShapeResourceWithRawResponse(self._client.shape)


class OnebusawaySDKWithStreamedResponse:
    _client: OnebusawaySDK

    def __init__(self, client: OnebusawaySDK) -> None:
        self._client = client

    @cached_property
    def agencies_with_coverage(self) -> agencies_with_coverage.AgenciesWithCoverageResourceWithStreamingResponse:
        from .resources.agencies_with_coverage import AgenciesWithCoverageResourceWithStreamingResponse

        return AgenciesWithCoverageResourceWithStreamingResponse(self._client.agencies_with_coverage)

    @cached_property
    def agency(self) -> agency.AgencyResourceWithStreamingResponse:
        from .resources.agency import AgencyResourceWithStreamingResponse

        return AgencyResourceWithStreamingResponse(self._client.agency)

    @cached_property
    def vehicles_for_agency(self) -> vehicles_for_agency.VehiclesForAgencyResourceWithStreamingResponse:
        from .resources.vehicles_for_agency import VehiclesForAgencyResourceWithStreamingResponse

        return VehiclesForAgencyResourceWithStreamingResponse(self._client.vehicles_for_agency)

    @cached_property
    def config(self) -> config.ConfigResourceWithStreamingResponse:
        from .resources.config import ConfigResourceWithStreamingResponse

        return ConfigResourceWithStreamingResponse(self._client.config)

    @cached_property
    def current_time(self) -> current_time.CurrentTimeResourceWithStreamingResponse:
        from .resources.current_time import CurrentTimeResourceWithStreamingResponse

        return CurrentTimeResourceWithStreamingResponse(self._client.current_time)

    @cached_property
    def stops_for_location(self) -> stops_for_location.StopsForLocationResourceWithStreamingResponse:
        from .resources.stops_for_location import StopsForLocationResourceWithStreamingResponse

        return StopsForLocationResourceWithStreamingResponse(self._client.stops_for_location)

    @cached_property
    def stops_for_route(self) -> stops_for_route.StopsForRouteResourceWithStreamingResponse:
        from .resources.stops_for_route import StopsForRouteResourceWithStreamingResponse

        return StopsForRouteResourceWithStreamingResponse(self._client.stops_for_route)

    @cached_property
    def stops_for_agency(self) -> stops_for_agency.StopsForAgencyResourceWithStreamingResponse:
        from .resources.stops_for_agency import StopsForAgencyResourceWithStreamingResponse

        return StopsForAgencyResourceWithStreamingResponse(self._client.stops_for_agency)

    @cached_property
    def stop(self) -> stop.StopResourceWithStreamingResponse:
        from .resources.stop import StopResourceWithStreamingResponse

        return StopResourceWithStreamingResponse(self._client.stop)

    @cached_property
    def stop_ids_for_agency(self) -> stop_ids_for_agency.StopIDsForAgencyResourceWithStreamingResponse:
        from .resources.stop_ids_for_agency import StopIDsForAgencyResourceWithStreamingResponse

        return StopIDsForAgencyResourceWithStreamingResponse(self._client.stop_ids_for_agency)

    @cached_property
    def schedule_for_stop(self) -> schedule_for_stop.ScheduleForStopResourceWithStreamingResponse:
        from .resources.schedule_for_stop import ScheduleForStopResourceWithStreamingResponse

        return ScheduleForStopResourceWithStreamingResponse(self._client.schedule_for_stop)

    @cached_property
    def route(self) -> route.RouteResourceWithStreamingResponse:
        from .resources.route import RouteResourceWithStreamingResponse

        return RouteResourceWithStreamingResponse(self._client.route)

    @cached_property
    def route_ids_for_agency(self) -> route_ids_for_agency.RouteIDsForAgencyResourceWithStreamingResponse:
        from .resources.route_ids_for_agency import RouteIDsForAgencyResourceWithStreamingResponse

        return RouteIDsForAgencyResourceWithStreamingResponse(self._client.route_ids_for_agency)

    @cached_property
    def routes_for_location(self) -> routes_for_location.RoutesForLocationResourceWithStreamingResponse:
        from .resources.routes_for_location import RoutesForLocationResourceWithStreamingResponse

        return RoutesForLocationResourceWithStreamingResponse(self._client.routes_for_location)

    @cached_property
    def routes_for_agency(self) -> routes_for_agency.RoutesForAgencyResourceWithStreamingResponse:
        from .resources.routes_for_agency import RoutesForAgencyResourceWithStreamingResponse

        return RoutesForAgencyResourceWithStreamingResponse(self._client.routes_for_agency)

    @cached_property
    def schedule_for_route(self) -> schedule_for_route.ScheduleForRouteResourceWithStreamingResponse:
        from .resources.schedule_for_route import ScheduleForRouteResourceWithStreamingResponse

        return ScheduleForRouteResourceWithStreamingResponse(self._client.schedule_for_route)

    @cached_property
    def arrival_and_departure(self) -> arrival_and_departure.ArrivalAndDepartureResourceWithStreamingResponse:
        from .resources.arrival_and_departure import ArrivalAndDepartureResourceWithStreamingResponse

        return ArrivalAndDepartureResourceWithStreamingResponse(self._client.arrival_and_departure)

    @cached_property
    def trip(self) -> trip.TripResourceWithStreamingResponse:
        from .resources.trip import TripResourceWithStreamingResponse

        return TripResourceWithStreamingResponse(self._client.trip)

    @cached_property
    def trips_for_location(self) -> trips_for_location.TripsForLocationResourceWithStreamingResponse:
        from .resources.trips_for_location import TripsForLocationResourceWithStreamingResponse

        return TripsForLocationResourceWithStreamingResponse(self._client.trips_for_location)

    @cached_property
    def trip_details(self) -> trip_details.TripDetailsResourceWithStreamingResponse:
        from .resources.trip_details import TripDetailsResourceWithStreamingResponse

        return TripDetailsResourceWithStreamingResponse(self._client.trip_details)

    @cached_property
    def trip_for_vehicle(self) -> trip_for_vehicle.TripForVehicleResourceWithStreamingResponse:
        from .resources.trip_for_vehicle import TripForVehicleResourceWithStreamingResponse

        return TripForVehicleResourceWithStreamingResponse(self._client.trip_for_vehicle)

    @cached_property
    def trips_for_route(self) -> trips_for_route.TripsForRouteResourceWithStreamingResponse:
        from .resources.trips_for_route import TripsForRouteResourceWithStreamingResponse

        return TripsForRouteResourceWithStreamingResponse(self._client.trips_for_route)

    @cached_property
    def report_problem_with_stop(self) -> report_problem_with_stop.ReportProblemWithStopResourceWithStreamingResponse:
        from .resources.report_problem_with_stop import ReportProblemWithStopResourceWithStreamingResponse

        return ReportProblemWithStopResourceWithStreamingResponse(self._client.report_problem_with_stop)

    @cached_property
    def report_problem_with_trip(self) -> report_problem_with_trip.ReportProblemWithTripResourceWithStreamingResponse:
        from .resources.report_problem_with_trip import ReportProblemWithTripResourceWithStreamingResponse

        return ReportProblemWithTripResourceWithStreamingResponse(self._client.report_problem_with_trip)

    @cached_property
    def search_for_stop(self) -> search_for_stop.SearchForStopResourceWithStreamingResponse:
        from .resources.search_for_stop import SearchForStopResourceWithStreamingResponse

        return SearchForStopResourceWithStreamingResponse(self._client.search_for_stop)

    @cached_property
    def search_for_route(self) -> search_for_route.SearchForRouteResourceWithStreamingResponse:
        from .resources.search_for_route import SearchForRouteResourceWithStreamingResponse

        return SearchForRouteResourceWithStreamingResponse(self._client.search_for_route)

    @cached_property
    def block(self) -> block.BlockResourceWithStreamingResponse:
        from .resources.block import BlockResourceWithStreamingResponse

        return BlockResourceWithStreamingResponse(self._client.block)

    @cached_property
    def shape(self) -> shape.ShapeResourceWithStreamingResponse:
        from .resources.shape import ShapeResourceWithStreamingResponse

        return ShapeResourceWithStreamingResponse(self._client.shape)


class AsyncOnebusawaySDKWithStreamedResponse:
    _client: AsyncOnebusawaySDK

    def __init__(self, client: AsyncOnebusawaySDK) -> None:
        self._client = client

    @cached_property
    def agencies_with_coverage(self) -> agencies_with_coverage.AsyncAgenciesWithCoverageResourceWithStreamingResponse:
        from .resources.agencies_with_coverage import AsyncAgenciesWithCoverageResourceWithStreamingResponse

        return AsyncAgenciesWithCoverageResourceWithStreamingResponse(self._client.agencies_with_coverage)

    @cached_property
    def agency(self) -> agency.AsyncAgencyResourceWithStreamingResponse:
        from .resources.agency import AsyncAgencyResourceWithStreamingResponse

        return AsyncAgencyResourceWithStreamingResponse(self._client.agency)

    @cached_property
    def vehicles_for_agency(self) -> vehicles_for_agency.AsyncVehiclesForAgencyResourceWithStreamingResponse:
        from .resources.vehicles_for_agency import AsyncVehiclesForAgencyResourceWithStreamingResponse

        return AsyncVehiclesForAgencyResourceWithStreamingResponse(self._client.vehicles_for_agency)

    @cached_property
    def config(self) -> config.AsyncConfigResourceWithStreamingResponse:
        from .resources.config import AsyncConfigResourceWithStreamingResponse

        return AsyncConfigResourceWithStreamingResponse(self._client.config)

    @cached_property
    def current_time(self) -> current_time.AsyncCurrentTimeResourceWithStreamingResponse:
        from .resources.current_time import AsyncCurrentTimeResourceWithStreamingResponse

        return AsyncCurrentTimeResourceWithStreamingResponse(self._client.current_time)

    @cached_property
    def stops_for_location(self) -> stops_for_location.AsyncStopsForLocationResourceWithStreamingResponse:
        from .resources.stops_for_location import AsyncStopsForLocationResourceWithStreamingResponse

        return AsyncStopsForLocationResourceWithStreamingResponse(self._client.stops_for_location)

    @cached_property
    def stops_for_route(self) -> stops_for_route.AsyncStopsForRouteResourceWithStreamingResponse:
        from .resources.stops_for_route import AsyncStopsForRouteResourceWithStreamingResponse

        return AsyncStopsForRouteResourceWithStreamingResponse(self._client.stops_for_route)

    @cached_property
    def stops_for_agency(self) -> stops_for_agency.AsyncStopsForAgencyResourceWithStreamingResponse:
        from .resources.stops_for_agency import AsyncStopsForAgencyResourceWithStreamingResponse

        return AsyncStopsForAgencyResourceWithStreamingResponse(self._client.stops_for_agency)

    @cached_property
    def stop(self) -> stop.AsyncStopResourceWithStreamingResponse:
        from .resources.stop import AsyncStopResourceWithStreamingResponse

        return AsyncStopResourceWithStreamingResponse(self._client.stop)

    @cached_property
    def stop_ids_for_agency(self) -> stop_ids_for_agency.AsyncStopIDsForAgencyResourceWithStreamingResponse:
        from .resources.stop_ids_for_agency import AsyncStopIDsForAgencyResourceWithStreamingResponse

        return AsyncStopIDsForAgencyResourceWithStreamingResponse(self._client.stop_ids_for_agency)

    @cached_property
    def schedule_for_stop(self) -> schedule_for_stop.AsyncScheduleForStopResourceWithStreamingResponse:
        from .resources.schedule_for_stop import AsyncScheduleForStopResourceWithStreamingResponse

        return AsyncScheduleForStopResourceWithStreamingResponse(self._client.schedule_for_stop)

    @cached_property
    def route(self) -> route.AsyncRouteResourceWithStreamingResponse:
        from .resources.route import AsyncRouteResourceWithStreamingResponse

        return AsyncRouteResourceWithStreamingResponse(self._client.route)

    @cached_property
    def route_ids_for_agency(self) -> route_ids_for_agency.AsyncRouteIDsForAgencyResourceWithStreamingResponse:
        from .resources.route_ids_for_agency import AsyncRouteIDsForAgencyResourceWithStreamingResponse

        return AsyncRouteIDsForAgencyResourceWithStreamingResponse(self._client.route_ids_for_agency)

    @cached_property
    def routes_for_location(self) -> routes_for_location.AsyncRoutesForLocationResourceWithStreamingResponse:
        from .resources.routes_for_location import AsyncRoutesForLocationResourceWithStreamingResponse

        return AsyncRoutesForLocationResourceWithStreamingResponse(self._client.routes_for_location)

    @cached_property
    def routes_for_agency(self) -> routes_for_agency.AsyncRoutesForAgencyResourceWithStreamingResponse:
        from .resources.routes_for_agency import AsyncRoutesForAgencyResourceWithStreamingResponse

        return AsyncRoutesForAgencyResourceWithStreamingResponse(self._client.routes_for_agency)

    @cached_property
    def schedule_for_route(self) -> schedule_for_route.AsyncScheduleForRouteResourceWithStreamingResponse:
        from .resources.schedule_for_route import AsyncScheduleForRouteResourceWithStreamingResponse

        return AsyncScheduleForRouteResourceWithStreamingResponse(self._client.schedule_for_route)

    @cached_property
    def arrival_and_departure(self) -> arrival_and_departure.AsyncArrivalAndDepartureResourceWithStreamingResponse:
        from .resources.arrival_and_departure import AsyncArrivalAndDepartureResourceWithStreamingResponse

        return AsyncArrivalAndDepartureResourceWithStreamingResponse(self._client.arrival_and_departure)

    @cached_property
    def trip(self) -> trip.AsyncTripResourceWithStreamingResponse:
        from .resources.trip import AsyncTripResourceWithStreamingResponse

        return AsyncTripResourceWithStreamingResponse(self._client.trip)

    @cached_property
    def trips_for_location(self) -> trips_for_location.AsyncTripsForLocationResourceWithStreamingResponse:
        from .resources.trips_for_location import AsyncTripsForLocationResourceWithStreamingResponse

        return AsyncTripsForLocationResourceWithStreamingResponse(self._client.trips_for_location)

    @cached_property
    def trip_details(self) -> trip_details.AsyncTripDetailsResourceWithStreamingResponse:
        from .resources.trip_details import AsyncTripDetailsResourceWithStreamingResponse

        return AsyncTripDetailsResourceWithStreamingResponse(self._client.trip_details)

    @cached_property
    def trip_for_vehicle(self) -> trip_for_vehicle.AsyncTripForVehicleResourceWithStreamingResponse:
        from .resources.trip_for_vehicle import AsyncTripForVehicleResourceWithStreamingResponse

        return AsyncTripForVehicleResourceWithStreamingResponse(self._client.trip_for_vehicle)

    @cached_property
    def trips_for_route(self) -> trips_for_route.AsyncTripsForRouteResourceWithStreamingResponse:
        from .resources.trips_for_route import AsyncTripsForRouteResourceWithStreamingResponse

        return AsyncTripsForRouteResourceWithStreamingResponse(self._client.trips_for_route)

    @cached_property
    def report_problem_with_stop(
        self,
    ) -> report_problem_with_stop.AsyncReportProblemWithStopResourceWithStreamingResponse:
        from .resources.report_problem_with_stop import AsyncReportProblemWithStopResourceWithStreamingResponse

        return AsyncReportProblemWithStopResourceWithStreamingResponse(self._client.report_problem_with_stop)

    @cached_property
    def report_problem_with_trip(
        self,
    ) -> report_problem_with_trip.AsyncReportProblemWithTripResourceWithStreamingResponse:
        from .resources.report_problem_with_trip import AsyncReportProblemWithTripResourceWithStreamingResponse

        return AsyncReportProblemWithTripResourceWithStreamingResponse(self._client.report_problem_with_trip)

    @cached_property
    def search_for_stop(self) -> search_for_stop.AsyncSearchForStopResourceWithStreamingResponse:
        from .resources.search_for_stop import AsyncSearchForStopResourceWithStreamingResponse

        return AsyncSearchForStopResourceWithStreamingResponse(self._client.search_for_stop)

    @cached_property
    def search_for_route(self) -> search_for_route.AsyncSearchForRouteResourceWithStreamingResponse:
        from .resources.search_for_route import AsyncSearchForRouteResourceWithStreamingResponse

        return AsyncSearchForRouteResourceWithStreamingResponse(self._client.search_for_route)

    @cached_property
    def block(self) -> block.AsyncBlockResourceWithStreamingResponse:
        from .resources.block import AsyncBlockResourceWithStreamingResponse

        return AsyncBlockResourceWithStreamingResponse(self._client.block)

    @cached_property
    def shape(self) -> shape.AsyncShapeResourceWithStreamingResponse:
        from .resources.shape import AsyncShapeResourceWithStreamingResponse

        return AsyncShapeResourceWithStreamingResponse(self._client.shape)


Client = OnebusawaySDK

AsyncClient = AsyncOnebusawaySDK



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from pydantic import Field as FieldInfo

from .._models import BaseModel
from .shared.references import References
from .shared.response_wrapper import ResponseWrapper

__all__ = [
    "ScheduleForStopRetrieveResponse",
    "ScheduleForStopRetrieveResponseData",
    "ScheduleForStopRetrieveResponseDataEntry",
    "ScheduleForStopRetrieveResponseDataEntryStopRouteSchedule",
    "ScheduleForStopRetrieveResponseDataEntryStopRouteScheduleStopRouteDirectionSchedule",
    "ScheduleForStopRetrieveResponseDataEntryStopRouteScheduleStopRouteDirectionScheduleScheduleStopTime",
    "ScheduleForStopRetrieveResponseDataEntryStopRouteScheduleStopRouteDirectionScheduleScheduleFrequency",
]


class ScheduleForStopRetrieveResponseDataEntryStopRouteScheduleStopRouteDirectionScheduleScheduleStopTime(BaseModel):
    arrival_enabled: bool = FieldInfo(alias="arrivalEnabled")

    arrival_time: int = FieldInfo(alias="arrivalTime")

    departure_enabled: bool = FieldInfo(alias="departureEnabled")

    departure_time: int = FieldInfo(alias="departureTime")

    service_id: str = FieldInfo(alias="serviceId")

    trip_id: str = FieldInfo(alias="tripId")

    stop_headsign: Optional[str] = FieldInfo(alias="stopHeadsign", default=None)


class ScheduleForStopRetrieveResponseDataEntryStopRouteScheduleStopRouteDirectionScheduleScheduleFrequency(BaseModel):
    end_time: int = FieldInfo(alias="endTime")

    headway: int

    service_date: int = FieldInfo(alias="serviceDate")

    service_id: str = FieldInfo(alias="serviceId")

    start_time: int = FieldInfo(alias="startTime")

    trip_id: str = FieldInfo(alias="tripId")


class ScheduleForStopRetrieveResponseDataEntryStopRouteScheduleStopRouteDirectionSchedule(BaseModel):
    schedule_stop_times: List[
        ScheduleForStopRetrieveResponseDataEntryStopRouteScheduleStopRouteDirectionScheduleScheduleStopTime
    ] = FieldInfo(alias="scheduleStopTimes")

    trip_headsign: str = FieldInfo(alias="tripHeadsign")

    schedule_frequencies: Optional[
        List[ScheduleForStopRetrieveResponseDataEntryStopRouteScheduleStopRouteDirectionScheduleScheduleFrequency]
    ] = FieldInfo(alias="scheduleFrequencies", default=None)


class ScheduleForStopRetrieveResponseDataEntryStopRouteSchedule(BaseModel):
    route_id: str = FieldInfo(alias="routeId")

    stop_route_direction_schedules: List[
        ScheduleForStopRetrieveResponseDataEntryStopRouteScheduleStopRouteDirectionSchedule
    ] = FieldInfo(alias="stopRouteDirectionSchedules")


class ScheduleForStopRetrieveResponseDataEntry(BaseModel):
    date: int

    stop_id: str = FieldInfo(alias="stopId")

    stop_route_schedules: List[ScheduleForStopRetrieveResponseDataEntryStopRouteSchedule] = FieldInfo(
        alias="stopRouteSchedules"
    )


class ScheduleForStopRetrieveResponseData(BaseModel):
    entry: ScheduleForStopRetrieveResponseDataEntry

    references: References


class ScheduleForStopRetrieveResponse(ResponseWrapper):
    data: ScheduleForStopRetrieveResponseData



from helpers.load_env import load_settings

from onebusaway import OnebusawaySDK

settings = load_settings(
    {
        "api_key": "TEST",
        "base_url": "https://api.pugetsound.onebusaway.org/",
    }
)

oba = OnebusawaySDK(**settings)

# Search for stops with the word "crystal" in them.
search_input = "crystal"

# Retrieve the search results.
response = oba.search_for_stop.list(input=search_input, max_count=5)

print(response.data)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..types import search_for_route_list_params
from .._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.search_for_route_list_response import SearchForRouteListResponse

__all__ = ["SearchForRouteResource", "AsyncSearchForRouteResource"]


class SearchForRouteResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> SearchForRouteResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/OneBusAway/python-sdk#accessing-raw-response-data-eg-headers
        """
        return SearchForRouteResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> SearchForRouteResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/OneBusAway/python-sdk#with_streaming_response
        """
        return SearchForRouteResourceWithStreamingResponse(self)

    def list(
        self,
        *,
        input: str,
        max_count: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SearchForRouteListResponse:
        """
        Search for a route based on its name.

        Args:
          input: The string to search for.

          max_count: The max number of results to return. Defaults to 20.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/api/where/search/route.json",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "input": input,
                        "max_count": max_count,
                    },
                    search_for_route_list_params.SearchForRouteListParams,
                ),
            ),
            cast_to=SearchForRouteListResponse,
        )


class AsyncSearchForRouteResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncSearchForRouteResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/OneBusAway/python-sdk#accessing-raw-response-data-eg-headers
        """
        return AsyncSearchForRouteResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncSearchForRouteResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/OneBusAway/python-sdk#with_streaming_response
        """
        return AsyncSearchForRouteResourceWithStreamingResponse(self)

    async def list(
        self,
        *,
        input: str,
        max_count: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SearchForRouteListResponse:
        """
        Search for a route based on its name.

        Args:
          input: The string to search for.

          max_count: The max number of results to return. Defaults to 20.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/api/where/search/route.json",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "input": input,
                        "max_count": max_count,
                    },
                    search_for_route_list_params.SearchForRouteListParams,
                ),
            ),
            cast_to=SearchForRouteListResponse,
        )


class SearchForRouteResourceWithRawResponse:
    def __init__(self, search_for_route: SearchForRouteResource) -> None:
        self._search_for_route = search_for_route

        self.list = to_raw_response_wrapper(
            search_for_route.list,
        )


class AsyncSearchForRouteResourceWithRawResponse:
    def __init__(self, search_for_route: AsyncSearchForRouteResource) -> None:
        self._search_for_route = search_for_route

        self.list = async_to_raw_response_wrapper(
            search_for_route.list,
        )


class SearchForRouteResourceWithStreamingResponse:
    def __init__(self, search_for_route: SearchForRouteResource) -> None:
        self._search_for_route = search_for_route

        self.list = to_streamed_response_wrapper(
            search_for_route.list,
        )


class AsyncSearchForRouteResourceWithStreamingResponse:
    def __init__(self, search_for_route: AsyncSearchForRouteResource) -> None:
        self._search_for_route = search_for_route

        self.list = async_to_streamed_response_wrapper(
            search_for_route.list,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from pydantic import Field as FieldInfo

from .._models import BaseModel
from .shared.references import References
from .shared.response_wrapper import ResponseWrapper

__all__ = [
    "VehiclesForAgencyListResponse",
    "VehiclesForAgencyListResponseData",
    "VehiclesForAgencyListResponseDataList",
    "VehiclesForAgencyListResponseDataListLocation",
    "VehiclesForAgencyListResponseDataListTripStatus",
    "VehiclesForAgencyListResponseDataListTripStatusLastKnownLocation",
    "VehiclesForAgencyListResponseDataListTripStatusPosition",
]


class VehiclesForAgencyListResponseDataListLocation(BaseModel):
    lat: Optional[float] = None

    lon: Optional[float] = None


class VehiclesForAgencyListResponseDataListTripStatusLastKnownLocation(BaseModel):
    """Last known location of the transit vehicle."""

    lat: Optional[float] = None
    """Latitude of the last known location of the transit vehicle."""

    lon: Optional[float] = None
    """Longitude of the last known location of the transit vehicle."""


class VehiclesForAgencyListResponseDataListTripStatusPosition(BaseModel):
    """Current position of the transit vehicle."""

    lat: Optional[float] = None
    """Latitude of the current position of the transit vehicle."""

    lon: Optional[float] = None
    """Longitude of the current position of the transit vehicle."""


class VehiclesForAgencyListResponseDataListTripStatus(BaseModel):
    active_trip_id: str = FieldInfo(alias="activeTripId")
    """Trip ID of the trip the vehicle is actively serving."""

    block_trip_sequence: int = FieldInfo(alias="blockTripSequence")
    """Index of the active trip into the sequence of trips for the active block."""

    closest_stop: str = FieldInfo(alias="closestStop")
    """ID of the closest stop to the current location of the transit vehicle."""

    distance_along_trip: float = FieldInfo(alias="distanceAlongTrip")
    """Distance, in meters, the transit vehicle has progressed along the active trip."""

    last_known_distance_along_trip: float = FieldInfo(alias="lastKnownDistanceAlongTrip")
    """
    Last known distance along the trip received in real-time from the transit
    vehicle.
    """

    last_location_update_time: int = FieldInfo(alias="lastLocationUpdateTime")
    """Timestamp of the last known real-time location update from the transit vehicle."""

    last_update_time: int = FieldInfo(alias="lastUpdateTime")
    """Timestamp of the last known real-time update from the transit vehicle."""

    occupancy_capacity: int = FieldInfo(alias="occupancyCapacity")
    """Capacity of the transit vehicle in terms of occupancy."""

    occupancy_count: int = FieldInfo(alias="occupancyCount")
    """Current count of occupants in the transit vehicle."""

    occupancy_status: str = FieldInfo(alias="occupancyStatus")
    """Current occupancy status of the transit vehicle."""

    phase: str
    """Current journey phase of the trip."""

    predicted: bool
    """Indicates if real-time arrival info is available for this trip."""

    schedule_deviation: int = FieldInfo(alias="scheduleDeviation")
    """Deviation from the schedule in seconds (positive for late, negative for early)."""

    service_date: int = FieldInfo(alias="serviceDate")
    """
    Time, in milliseconds since the Unix epoch, of midnight for the start of the
    service date for the trip.
    """

    status: str
    """Current status modifiers for the trip."""

    total_distance_along_trip: float = FieldInfo(alias="totalDistanceAlongTrip")
    """Total length of the trip, in meters."""

    closest_stop_time_offset: Optional[int] = FieldInfo(alias="closestStopTimeOffset", default=None)
    """
    Time offset from the closest stop to the current position of the transit vehicle
    (in seconds).
    """

    frequency: Optional[str] = None
    """Information about frequency-based scheduling, if applicable to the trip."""

    last_known_location: Optional[VehiclesForAgencyListResponseDataListTripStatusLastKnownLocation] = FieldInfo(
        alias="lastKnownLocation", default=None
    )
    """Last known location of the transit vehicle."""

    last_known_orientation: Optional[float] = FieldInfo(alias="lastKnownOrientation", default=None)
    """Last known orientation value received in real-time from the transit vehicle."""

    next_stop: Optional[str] = FieldInfo(alias="nextStop", default=None)
    """ID of the next stop the transit vehicle is scheduled to arrive at."""

    next_stop_time_offset: Optional[int] = FieldInfo(alias="nextStopTimeOffset", default=None)
    """
    Time offset from the next stop to the current position of the transit vehicle
    (in seconds).
    """

    orientation: Optional[float] = None
    """Orientation of the transit vehicle, represented as an angle in degrees."""

    position: Optional[VehiclesForAgencyListResponseDataListTripStatusPosition] = None
    """Current position of the transit vehicle."""

    scheduled_distance_along_trip: Optional[float] = FieldInfo(alias="scheduledDistanceAlongTrip", default=None)
    """
    Distance, in meters, the transit vehicle is scheduled to have progressed along
    the active trip.
    """

    situation_ids: Optional[List[str]] = FieldInfo(alias="situationIds", default=None)
    """References to situation elements (if any) applicable to this trip."""

    vehicle_id: Optional[str] = FieldInfo(alias="vehicleId", default=None)
    """ID of the transit vehicle currently serving the trip."""


class VehiclesForAgencyListResponseDataList(BaseModel):
    last_location_update_time: int = FieldInfo(alias="lastLocationUpdateTime")

    last_update_time: int = FieldInfo(alias="lastUpdateTime")

    location: VehiclesForAgencyListResponseDataListLocation

    trip_id: str = FieldInfo(alias="tripId")

    trip_status: VehiclesForAgencyListResponseDataListTripStatus = FieldInfo(alias="tripStatus")

    vehicle_id: str = FieldInfo(alias="vehicleId")

    occupancy_capacity: Optional[int] = FieldInfo(alias="occupancyCapacity", default=None)

    occupancy_count: Optional[int] = FieldInfo(alias="occupancyCount", default=None)

    occupancy_status: Optional[str] = FieldInfo(alias="occupancyStatus", default=None)

    phase: Optional[str] = None

    status: Optional[str] = None


class VehiclesForAgencyListResponseData(BaseModel):
    limit_exceeded: bool = FieldInfo(alias="limitExceeded")

    list: List[VehiclesForAgencyListResponseDataList]

    references: References


class VehiclesForAgencyListResponse(ResponseWrapper):
    data: VehiclesForAgencyListResponseData



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["StopsForLocationListParams"]


class StopsForLocationListParams(TypedDict, total=False):
    lat: Required[float]

    lon: Required[float]

    lat_span: Annotated[float, PropertyInfo(alias="latSpan")]
    """An alternative to radius to set the search bounding box (optional)"""

    lon_span: Annotated[float, PropertyInfo(alias="lonSpan")]
    """An alternative to radius to set the search bounding box (optional)"""

    query: str
    """A search query string to filter the results"""

    radius: float
    """The radius in meters to search within"""
